.. stis_cti documentation master file, created by
   sphinx-quickstart on Mon Jun  8 19:34:11 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

stis_cti's Documentation
========================
`Project Homepage`_ — `GitHub`_ — `PyPI`_

.. _GitHub: https://github.com/spacetelescope/stis_cti
.. _Project Homepage: https://www.stsci.edu/hst/instrumentation/stis/data-analysis-and-software-tools/pixel-based-cti
.. _PyPI: https://pypi.org/project/stis-cti

.. toctree::
   :maxdepth: 3
   
   qsg.rst
   readme.rst
   stis_cti.rst
